using MediatR;
using Sledgemapper.Api.Commands;
using Sledgemapper.Api.Notifications;
using Sledgemapper.Api.Infrastructure.Data;
using Sledgemapper.Shared.Entities;
using System.Linq;
using System.Text.Json;
using System.Threading;
using System.Threading.Tasks;

namespace Sledgemapper.Api.Handlers
{
    public class DeleteTileCommandHandler : IRequestHandler<DeleteTileCommand,bool>
    {
         private readonly SledgemapperDbContext _dbcontext;

        private readonly IMediator _mediator;

        public DeleteTileCommandHandler(IMediator mediator, SledgemapperDbContext dbcontext) { _dbcontext = dbcontext; _mediator = mediator; }

        public async Task<bool> Handle(DeleteTileCommand notification, CancellationToken cancellationToken)
        {
            var jsonString = JsonSerializer.Serialize(notification.Tile);
            var session = _dbcontext.Sessions.First(m=>m.SessionName== notification.SessionName);

            _dbcontext.MapLogs.Add(new Models.MapLog
            {
                Operation = "D",
                SessionId = session.SessionId,
                Type = "T",
                Timestamp = notification.Timestamp,
                Object = jsonString,
                UserId = notification.UserId
            });
            await _dbcontext.SaveChangesAsync();
            await _mediator.Publish(new DeleteTileNotification(session, notification.Tile, notification.UserId));
            return true;
        }
    }
}
